@@ -1,4 +1,12 @@
-__version__ = "1.1.0"
+"""
+```{warning}
+Do not manually change this information.
+```
+
+Metadata information about Finalynx. This file is used by Fynalinx and updated by the CI/CD pipeline.
+"""
+
+__version__ = "1.4.0"
 
 __author__ = "Pierre Laclau (MadeInPierre)"
 
